# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from ......schema_classes import GlobalSettingsInfoClass
from ......schema_classes import GlobalViewsSettingsClass


GlobalSettingsInfo = GlobalSettingsInfoClass
GlobalViewsSettings = GlobalViewsSettingsClass

# fmt: on
